@@ -428,7 +428,7 @@ NTV2BreakoutType CNTV2Card::GetBreakoutHardware (void)
 				break;
 			case DEVICE_ID_KONAX:
 				// Do we have a BOB?
-				if(IsBreakoutBoardConnected())
+				if (IsSupported(kDeviceHasBreakoutBoard))
 					result = NTV2_BreakoutBoard;
 				break;
 			default:
@@ -490,7 +490,7 @@ bool CNTV2Card::GetLPTunnelConfigurationURLString (string & outURLString)
 	return true;
 }
 
-int CNTV2Card::GetSFPURLs(std::vector<std::string> & OutSFPURLStrings)
+int CNTV2Card::GetSFPConfigurationURLStrings(std::vector<std::string> & OutSFPURLStrings)
 {
 	if (!NTV2DeviceHasLPProductCode(GetDeviceID()) || NTV2DeviceGetNum25GSFPs(GetDeviceID()) == 0)
 		return 0;
