@@ -12,9 +12,11 @@
 #include "ajabase/system/debug.h"
 #include "ajabase/common/common.h"
 #include "ajabase/system/systemtime.h"
-#include "ajabase/system/thread.h"
+#include "ajabase/system/atomic.h"
 #include <iomanip>
 #if !defined(NTV2_PREVENT_PLUGIN_LOAD)
+	#include "ajabase/common/ajarefptr.h"
+	#include "ajabase/system/thread.h"
 	#include <fstream>
 	#include "mbedtls/x509.h"
 	#include "mbedtls/error.h"
@@ -94,16 +96,16 @@ using namespace std;
 
 
 //	Stats
-static uint32_t gBaseConstructCount(0);		//	Number of NTV2RPCBase constructor calls made
-static uint32_t gBaseDestructCount(0);		//	Number of NTV2RPCBase destructor calls made
-static uint32_t gClientConstructCount(0);	//	Number of NTV2RPCClient constructor calls made
-static uint32_t gClientDestructCount(0);	//	Number of NTV2RPCClient destructor calls made
-static uint32_t gServerConstructCount(0);	//	Number of NTV2RPCServer constructor calls made
-static uint32_t gServerDestructCount(0);	//	Number of NTV2RPCServer destructor calls made
-static uint32_t gLoaderConstructCount(0);	//	Number of NTV2PluginLoader constructor calls made
-static uint32_t gLoaderDestructCount(0);	//	Number of NTV2PluginLoader destructor calls made
-static uint32_t gPluginConstructCount(0);	//	Number of NTV2Plugin constructor calls made
-static uint32_t gPluginDestructCount(0);	//	Number of NTV2Plugin destructor calls made
+uint32_t gBaseConstructCount(0);		//	Number of NTV2RPCBase constructor calls made
+uint32_t gBaseDestructCount(0);		//	Number of NTV2RPCBase destructor calls made
+uint32_t gClientConstructCount(0);	//	Number of NTV2RPCClient constructor calls made
+uint32_t gClientDestructCount(0);	//	Number of NTV2RPCClient destructor calls made
+uint32_t gServerConstructCount(0);	//	Number of NTV2RPCServer constructor calls made
+uint32_t gServerDestructCount(0);	//	Number of NTV2RPCServer destructor calls made
+uint32_t gLoaderConstructCount(0);	//	Number of NTV2PluginLoader constructor calls made
+uint32_t gLoaderDestructCount(0);	//	Number of NTV2PluginLoader destructor calls made
+uint32_t gPluginConstructCount(0);	//	Number of NTV2Plugin constructor calls made
+uint32_t gPluginDestructCount(0);	//	Number of NTV2Plugin destructor calls made
 
 
 string NTV2Dictionary::valueForKey (const string & inKey) const
@@ -558,7 +560,7 @@ bool NTV2DeviceSpecParser::ParseAlphaNumeric (size_t & pos, string & outToken, c
 			break;
 		++pos;  tokAlphaNum += ch;
 	}
-	if (tokAlphaNum.length() > 1)	//	At least 2 chars
+	if (tokAlphaNum.length() > 0)
 		outToken = tokAlphaNum;
 	return !outToken.empty();
 }
@@ -646,7 +648,7 @@ bool NTV2DeviceSpecParser::ParseModelName (size_t & pos, string & outToken)
 {
 	outToken.clear();
 	string tokName;
-	if (!ParseAlphaNumeric(pos, tokName))
+	if (!ParseAlphaNumeric(pos, tokName, " "))
 		return false;
 	aja::lower(tokName);	//	Fold to lower case
 
@@ -745,7 +747,7 @@ bool NTV2DeviceSpecParser::ParseResourcePath (size_t & pos, string & outRsrc)
 	{
 		++rsrcPos;
 		rsrc += '/';
-		if (!ParseAlphaNumeric(rsrcPos, name))
+		if (!ParseAlphaNumeric(rsrcPos, name, " "))
 			break;
 		rsrc += name;
 		ch = CharAt(rsrcPos);
@@ -983,7 +985,7 @@ bool NTV2Plugin::LoadPlugin (const string & path, const string & folderPath, NTV
 			loadErr << "AddDllDirectory '" << path << "' failed: " << WinErrStr(::GetLastError());
 			return false;
 		}	//	AddDllDirectory failed
-		HMODULE h = ::LoadLibraryExA(LPCSTR(path.c_str()), AJA_NULL, LOAD_LIBRARY_SEARCH_USER_DIRS);
+		HMODULE h = ::LoadLibraryExA(LPCSTR(path.c_str()), AJA_NULL, LOAD_LIBRARY_SEARCH_DEFAULT_DIRS);
 		if (!h)
 			loadErr << "Unable to open '" << path << "': " << WinErrStr(::GetLastError());
 	#else	//	MacOS or Linux
