@@ -4,7 +4,7 @@
 
 #if defined( AJAMac ) || defined( AJALinux )
 #include <GL/glew.h>
-#include <GL/glut.h>
+// #include <GL/glut.h>
 #include <GL/gl.h>
 #include <GL/glx.h>
 #else
